@@ -1,4 +1,5 @@
 import coverage
+from django_coverage.utils.module_tools import get_all_modules
 from discover_runner import DiscoverRunner
 
 from discoverage.settings import OMIT_MODULES, APPS_TEST_CASE_ATTR
@@ -9,7 +10,7 @@ def find_coverage_apps(suite):
         apps = getattr(test, APPS_TEST_CASE_ATTR, ())
         for app in apps:
             coverage_apps.add(app)
-    return coverage_apps
+    return list(coverage_apps)
 
 
 class DiscoverageRunner(DiscoverRunner):
@@ -21,13 +22,17 @@ class DiscoverageRunner(DiscoverRunner):
 
     def run_tests(self, test_labels, extra_tests=None, **kwargs):
         suite = self.build_suite(test_labels, extra_tests)
-        coverage_modules = find_coverage_apps(suite)
-        cov = coverage.coverage(source=coverage_modules, omit=OMIT_MODULES)
+        apps = find_coverage_apps(suite)
+        cov = coverage.coverage(source=apps, omit=OMIT_MODULES)
+
         cov.start()
         result = super(DiscoverageRunner, self).run_tests(test_labels,
                                                           extra_tests=None,
                                                           **kwargs)
         cov.stop()
+
+        module_data = get_all_modules(apps, [], [])
         print
-        cov.report()
+        cov.report(module_data[1].values())
+
         return result
